class Enviador:
    def enviar(self, remetente, destinatario, assunto, corpo):
        if "@" not in remetente:
            raise EmailInvalido(f"Email de remetente invalido: {remetente}")
        return remetente


class EmailInvalido(Exception):
    pass



import pytest as pytest

from libpythonprogoldani.spam.enviador_de_email import Enviador
from libpythonprogoldani.spam.enviador_de_email import EmailInvalido


def test_criar_enviador_de_email():
    enviador = Enviador()
    assert enviador is not None


@pytest.mark.parametrize("remetente", ["foo@ba.com.br", "gustavo@gmail.com"])
def test_remetente(remetente):
    enviador = Enviador()
    resultado = enviador.enviar(
        remetente, "goldani@gmail.com", "Curso PythonPro", "Turma Henrique Bastos"
    )
    assert remetente in resultado


@pytest.mark.parametrize("remetente", ["", "gustavo"])
def test_remetente_invalido(remetente):
    enviador = Enviador()
    with pytest.raises(EmailInvalido):
        enviador.enviar(
            remetente, "goldani@gmail.com", "Curso PythonPro", "Turma Henrique Bastos"
        )



import requests


def buscar_avatar(usuario):
    """
    Busca o avatar de um usuário no Github

    :param usuario: str com o nome de usuário no github
    :return: str com o link do avatar
    """
    url = f"https://api.github.com/users/{usuario}"
    resposta = requests.get(url)
    return resposta.json()["avatar_url"]
